@@ -261,11 +261,13 @@ class SyncGUI(object):
     self.init_server_create()
   def delete_servers(self, button):
     self.init_server_delete()
-  def load_cookie(self):
+  def load_server_cookie(self, server_dir):
     try:
-      self.server_cookie = int(open(self.server_dir + "/.alarmcookie", "r").read())
+      return int(open(server_dir + "/.alarmcookie", "r").read())
     except:
-      self.server_cookie = None
+      return None
+  def load_cookie(self):
+    self.server_cookie = self.load_server_cookie(self.server_dir)
 ### SERVER DELETION
   def init_server_delete(self):
     window = hildon.StackableWindow()
@@ -303,11 +305,18 @@ class SyncGUI(object):
       note.destroy()
     if response == gtk.RESPONSE_OK:
       for server in servers:
-        self.sync.delete_server(server)
+        self.do_delete_server(server)
       self.server_delete_close(button, window)
       self.init_main_selector()
   def server_delete_close(self, button, window):
     window.destroy()
+  def do_delete_server(self, server):
+    server_dir = self.sync.get_server_dir(server)
+    server_cookie = load_server_cookie(server_dir)
+    if not server_cookie is None:
+      os.unlink(server_dir + "/.alarmcookie")
+      alarm.delete_event(server_cookie)
+    self.sync.delete_server(server)
 
 ### SERVER CREATION
   def init_server_create(self):
@@ -507,7 +516,7 @@ class SyncGUI(object):
     response = gtk.Dialog.run(note)
     note.destroy()
     if response == gtk.RESPONSE_OK:
-      self.sync.delete_server(self.server)
+      self.do_delete_server(self.server)
       self.server_window.destroy()
       self.init_main_selector()
   def sync_clicked(self, button):
@@ -584,7 +593,7 @@ class SyncGUI(object):
   def init_server_history(self):
     self.history_window = hildon.StackableWindow()
     self.history_window.set_title(self.get_history_title())
-    self.history_window.connect("destroy", self.destroy_server_config)
+    self.history_window.connect("destroy", self.destroy_server_history)
     self.program.add_window(self.history_window)
 
     self.server_sessions = self.sync.get_sessions(self.server)
